Name:           derby
Version:        10.6.2.1
Release:        %mkrel 1
Summary:        Relational database implemented entirely in Java

Group:          Development/Java
License:        ASL 2.0
URL:            http://db.apache.org/derby/
#Source0:        http://www.apache.org/dist/db/%{name}/db-%{name}-%{version}/db-%{name}-%{version}-src.tar.gz
Source0:        http://archive.apache.org/dist/db/derby/db-derby-10.6.2.1/db-derby-10.6.2.1-src.tar.gz
Source1:        derby-script

Source8:        get-derby-pom.sh
# sh %{SOURCE8}
Source9:        derby-poms-%{version}.tar.gz

BuildRequires:  java-devel >= 1.6
BuildRequires:  jpackage-utils
BuildRequires:  tomcat6-servlet-2.5-api
BuildRequires:  jakarta-oro
BuildRequires:  javacc
BuildRequires:  junit4
BuildRequires:  xalan-j2
BuildRequires:  xerces-j2
BuildRequires:  ant-nodeps
Requires:       java
Requires:       jpackage-utils

BuildArch:      noarch

%description
Apache Derby, an Apache DB sub-project, is a relational database implemented
entirely in Java. Some key advantages include a small footprint, conformance
to Java, JDBC, and SQL standards and embedded JDBC driver.


%prep
%setup -q -c

%build
cd db-%{name}-%{version}-src
find -name '*.jar' -delete

# tools/ant/properties/extrapath.properties
ln -sf $(build-classpath javacc) tools/java/javacc.jar
ln -sf $(build-classpath tomcat6-servlet-2.5-api) \
        tools/java/geronimo-spec-servlet-2.4-rc4.jar
ln -sf $(build-classpath xalan-j2) tools/java/xalan.jar
ln -sf $(build-classpath oro) tools/java/jakarta-oro-2.0.8.jar
ln -sf $(build-classpath xerces-j2) tools/java/xercesImpl.jar
ln -sf $(build-classpath xalan-j2-serializer) tools/java/serializer.jar
ln -sf $(build-classpath junit4) tools/java/junit.jar

# Using generics
find -name build.xml |xargs sed '
        s/target="1.4"/target="1.5"/
        s/source="1.4"/source="1.5"/
        /Class-Path/d
' -i

# Fire
ant buildsource -Dderby.source.rpm=%{version}
ant buildjars -Dderby.source.rpm=%{version}


%install
cd db-%{name}-%{version}-src
rm -rf $RPM_BUILD_ROOT

# Library
install -d $RPM_BUILD_ROOT%{_javadir}/%{name}
for i in jars/sane/*.jar
do
        B=$(basename $i |sed 's/.jar$//')
        install -m644 $i $RPM_BUILD_ROOT%{_javadir}/%{name}/$B-%{version}.jar
        ln -sf $B-%{version}.jar $RPM_BUILD_ROOT%{_javadir}/%{name}/$B.jar
done

# We hardlink instead of symlinking so that default security policy
# applies to derbynet.jar
ln -f $RPM_BUILD_ROOT%{_javadir}/%{name}/derbynet-%{version}.jar \
        $RPM_BUILD_ROOT%{_javadir}/%{name}/derbynet.jar


# Wrapper scripts
install -d $RPM_BUILD_ROOT%{_bindir}
install -p -m755 %{SOURCE1} $RPM_BUILD_ROOT%{_bindir}/%{name}-ij
for P in sysinfo NetworkServerControl startNetworkServer stopNetworkServer
do
        ln $RPM_BUILD_ROOT%{_bindir}/%{name}-ij \
                $RPM_BUILD_ROOT%{_bindir}/%{name}-$P
done

# POMs & Dependency maps
install -d $RPM_BUILD_ROOT%{_mavenpomdir}
(
  cd maven2

  sed -i "s|<version>ALPHA_VERSION</version>|<version>%{version}</version>|" $(find . -name "pom.xml")

  install -p -m644 pom.xml $RPM_BUILD_ROOT%{_mavenpomdir}/JPP.%{name}-%{name}-project.pom
  %add_to_maven_depmap org.apache.%{name} %{name}-project %{version} JPP/%{name} %{name}-project
  install -p -m644 engine/pom.xml $RPM_BUILD_ROOT%{_mavenpomdir}/JPP.%{name}-%{name}.pom
  %add_to_maven_depmap org.apache.%{name} %{name} %{version} JPP/%{name} %{name}
  install -p -m644 client/pom.xml $RPM_BUILD_ROOT%{_mavenpomdir}/JPP.%{name}-%{name}client.pom
  %add_to_maven_depmap org.apache.%{name} %{name}client %{version} JPP/%{name} %{name}client
  install -p -m644 net/pom.xml $RPM_BUILD_ROOT%{_mavenpomdir}/JPP.%{name}-%{name}net.pom
  %add_to_maven_depmap org.apache.%{name} %{name}net %{version} JPP/%{name} %{name}net
  install -p -m644 tools/pom.xml $RPM_BUILD_ROOT%{_mavenpomdir}/JPP.%{name}-%{name}tools.pom
  %add_to_maven_depmap org.apache.%{name} %{name}tools %{version} JPP/%{name} %{name}tools

  for locpom in cs de_DE es fr hu it ja_JP ko_KR pl pt_BR ru zh_CN zh_TW ; do
      install -p -m644 %{name}Locale_$locpom/pom.xml $RPM_BUILD_ROOT%{_mavenpomdir}/JPP.%{name}-%{name}Locale_$locpom.pom
      %add_to_maven_depmap org.apache.%{name} %{name}Locale_$locpom %{version} JPP/%{name} %{name}Locale_$locpom
  done
)

%check
#TODO
#ant junit-all


%clean
rm -rf $RPM_BUILD_ROOT


%post
%update_maven_depmap


%postun
%update_maven_depmap


%files
%defattr(-,root,root,-)
%{_bindir}/*
%{_javadir}/%{name}
%doc db-%{name}-%{version}-src/LICENSE
%doc db-%{name}-%{version}-src/NOTICE
%doc db-%{name}-%{version}-src/published_api_overview.html
%doc db-%{name}-%{version}-src/RELEASE-NOTES.html
%doc db-%{name}-%{version}-src/README
%{_mavenpomdir}/*.pom
%{_mavendepmapfragdir}/%{name}




%changelog

* Thu Dec 15 2011 gil <gil> 10.6.2.1-1.mga2
+ Revision: 181761
- update to 10.6.2.1

* Thu Apr 28 2011 dmorgan <dmorgan> 10.6.1.0-7.mga1
+ Revision: 92433
- Rebuild after bootstrapping
- imported package derby


* Fri Feb 25 2011 Lubomir Rintel <lkundrak@v3.sk> - 10.6.1.0-6
- Fix startup script (Thomas Meyer, #668828)

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 10.6.1.0-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Fri Nov 26 2010 Stanislav Ochotnicky <sochotnicky@redhat.com> - 10.6.1.0-4
- Fix pom filenames (Resolves rhbz#655794)

* Tue Jul 27 2010 Lubomir Rintel <lkundrak@v3.sk> - 10.6.1.0-3
- Fix buildrequires

* Tue Jul 27 2010 Lubomir Rintel <lkundrak@v3.sk> - 10.6.1.0-2
- Add tool launchers
- Add POMs

* Mon Jun 28 2010 Lubomir Rintel <lkundrak@v3.sk> - 10.6.1.0-1
- Initial packaging
